@@ -4,8 +4,8 @@
 #'
 #' @inheritParams runonce-package
 #' @param code Code to run. Do not forget to wrap it with `{ }`. Also, beware
-#'   that it is your job to make sure your code and data has not changed. If this
-#'   is the case, you need to remove the `file` storing the outdated result.
+#'   that **it is your job to make sure your code and data has not changed**. If
+#'   this is the case, you need to remove the `file` storing the outdated result.
 #' @param file File path where the result is stored. Should have extension `rds`.
 #'
 #' @return The evaluation of `code` the first time, the content of `file` otherwise.
@@ -16,17 +16,11 @@
 #' tmp <- tempfile(fileext = ".rds")
 #'
 #' # Run once because result does not exist yet
-#' save_run({
-#'   Sys.sleep(2)
-#'   1
-#' }, file = tmp)
+#' save_run({ Sys.sleep(1); 1 }, file = tmp)
 #'
 #' # Skip run because the result already exists
 #' # (but still output how long it took the first time)
-#' save_run({
-#'   Sys.sleep(2)
-#'   1
-#' }, file = tmp)
+#' Sys.sleep(1); save_run({ Sys.sleep(1); 1 }, file = tmp)
 #'
 save_run <- function(code, file, timing = TRUE) {
 
@@ -38,20 +32,24 @@ save_run <- function(code, file, timing = TRUE) {
 
     res <- readRDS(file)
 
-    time <- attr(res, "RUNONCE_TIMING")
-    attr(res, "RUNONCE_TIMING") <- NULL
+    runtime <- attr(res, "RUNONCE_TIMING"); attr(res, "RUNONCE_TIMING") <- NULL
+    time    <- attr(res, "RUNONCE_TIME");   attr(res, "RUNONCE_TIME")   <- NULL
 
   } else {
 
-    time <- system.time(
+    runtime <- system.time(
       res <- code
     )
+    time <- Sys.time()
 
-    saveRDS(structure(res, RUNONCE_TIMING = time), file)
+    saveRDS(structure(res, RUNONCE_TIMING = runtime, RUNONCE_TIME = time),
+            file)
 
   }
 
-  if (timing && !is.null(time)) print(time)
+  if (timing && !is.null(runtime)) print(runtime)
+  if (timing && !is.null(time))
+    cat("Code finished running at", format(time, "%Y-%m-%d %H:%M:%S %Z"), "\n")
 
   res
 }
